@@ -1,8 +1,6 @@
 # Ultralytics MkDocs plugin 🚀, AGPL-3.0 license
 
-
 import json
-from datetime import datetime
 from pathlib import Path
 from subprocess import check_output
 
@@ -10,8 +8,7 @@ from bs4 import BeautifulSoup
 from mkdocs.config import config_options
 from mkdocs.plugins import BasePlugin
 
-# import get_github_usernames_from_file function from the previous script
-from .utils import (
+from plugin.utils import (
     calculate_time_difference,
     get_github_usernames_from_file,
     get_youtube_video_ids,
@@ -19,17 +16,33 @@ from .utils import (
 
 
 class MetaPlugin(BasePlugin):
-    # Plugin arguments
+    """
+    MetaPlugin class for enhancing MkDocs documentation with metadata, social sharing, and structured data.
+
+    This class extends the BasePlugin class from MkDocs to add various meta tags, social sharing buttons, and
+    structured data to the generated HTML pages. It also retrieves git information for each file to include
+    authorship and modification details.
+
+    Methods:
+        get_git_info: Retrieves git information of a specified file including hash, date, and branch.
+        on_page_content: Processes page content with optional enhancements like images, descriptions, and keywords.
+        insert_content: Inserts additional content into a BeautifulSoup object at a specified location.
+        parse_faq: Parses the FAQ questions and answers from the HTML page content.
+        on_post_page: Enhances the HTML output of a page with metadata tags, git information, and share buttons.
+        get_css: Provides simplified CSS for styling the added elements.
+    """
+
     config_scheme = (
-        ("verbose", config_options.Type(bool, default=True)),
-        ("enabled", config_options.Type(bool, default=True)),
-        ("default_image", config_options.Type(str, default=None)),
-        ("add_desc", config_options.Type(bool, default=True)),
-        ("add_image", config_options.Type(bool, default=True)),
-        ("add_keywords", config_options.Type(bool, default=True)),  # Add new argument for keywords
-        ("add_share_buttons", config_options.Type(bool, default=True)),  # Add new argument
-        ("add_authors", config_options.Type(bool, default=False)),  # Add dates and authors section
+        ("verbose", config_options.Type(bool, default=True)),  # Enable verbose output for debugging
+        ("enabled", config_options.Type(bool, default=True)),  # Enable or disable the plugin
+        ("default_image", config_options.Type(str, default=None)),  # Default image URL if none found in content
+        ("add_desc", config_options.Type(bool, default=True)),  # Add meta description tags
+        ("add_image", config_options.Type(bool, default=True)),  # Add meta image tags
+        ("add_keywords", config_options.Type(bool, default=True)),  # Add meta keywords tags
+        ("add_share_buttons", config_options.Type(bool, default=True)),  # Add social share buttons
+        ("add_authors", config_options.Type(bool, default=False)),  # Add git author and date information
         ("add_json_ld", config_options.Type(bool, default=False)),  # Add JSON-LD structured data
+        ("add_css", config_options.Type(bool, default=True)),  # Inline CSS for styling
     )
 
     def get_git_info(self, file_path):
@@ -325,121 +338,59 @@ class MetaPlugin(BasePlugin):
         # Add git information (dates and authors) to the footer, if enabled
         git_info = self.get_git_info(page.file.abs_src_path)
         if (self.config["add_authors"]) and git_info["creation_date"]:
-            date_format = "%Y-%m-%d %H:%M:%S %z"
-            created_ago = calculate_time_difference(git_info["creation_date"])
-            updated_ago = calculate_time_difference(git_info["last_modified_date"])
-            created_date = datetime.strptime(git_info["creation_date"], date_format).strftime("%B %d, %Y")
-            updated_date = datetime.strptime(git_info["last_modified_date"], date_format).strftime("%B %d, %Y")
+            created_ago, created_date = calculate_time_difference(git_info["creation_date"])
+            updated_ago, updated_date = calculate_time_difference(git_info["last_modified_date"])
 
-            div = '<div class="git-info">'
-
-            div += f"""
-            <span class="dates">
-                <span title="This page was first created on {created_date}">
-                    <span class="hover-item">📅</span> Created {created_ago} ago
-                </span>
-                &nbsp;
-                <span title="This page was last updated on {updated_date}">
-                    <span class="hover-item">✏️</span> Updated {updated_ago} ago
-                </span>
-                &nbsp;
-            </span>
-            """
+            div = f"""<div class="git-info">
+<div class="dates-container">
+    <span class="date-item" title="This page was first created on {created_date}">
+        <span class="hover-item">📅</span> Created {created_ago} ago
+    </span>
+    <span class="date-item" title="This page was last updated on {updated_date}">
+        <span class="hover-item">✏️</span> Updated {updated_ago} ago
+    </span>
+</div>
+<div class="authors-container">
+"""
 
             if self.config["add_authors"]:
                 for author in git_info["authors"]:
-                    div += f"""
-                    <a href="{author[1]}" class="author-link" title="{author[0]} ({author[2]} changes)">
-                        <img src="https://github.com/{author[0]}.png" alt="{author[0]}" class="hover-item">
-                    </a>
-                    """
+                    name, url, n = author  # n is number of changes
+                    if "@" in name:  # This is an email address
+                        div += f"""<span class="author-link" title="{name} ({n} change{'s' * (n > 1)})">
+    <img src="https://github.com/github.png" alt="Author" class="hover-item">
+</span>
+"""
+                    else:  # This is a GitHub username
+                        div += f"""<a href="{url}" class="author-link" title="{name} ({n} change{'s' * (n > 1)})">
+    <img src="https://github.com/{name}.png" alt="{name}" class="hover-item">
+</a>
+"""
 
-            div += "</div>"
+            div += "</div></div>"
+
+            if self.config["add_css"]:
+                style_tag = soup.new_tag("style")
+                style_tag.string = self.get_css()
+                soup.head.append(style_tag)
 
-            # Simplified CSS with unified hover effects, closer author circles, and larger share buttons
-            css = """
-            <style>
-                .git-info, .share-buttons {
-                    font-size: 0.8em;
-                    color: grey;
-                    display: flex;
-                    align-items: center;
-                    justify-content: flex-end;
-                    margin-bottom: 10px;
-                }
-                .dates {
-                    display: flex;
-                    align-items: center;
-                }
-                .dates span, .author-link, .share-button {
-                    cursor: pointer;
-                    display: flex;
-                    align-items: center;
-                }
-                .dates span {
-                    margin-right: 10px;
-                }
-                .hover-item {
-                    transition: all 0.2s ease;
-                    filter: grayscale(100%);
-                }
-                .dates .hover-item {
-                    font-size: 1.6em;
-                    margin-right: 5px;
-                }
-                .author-link .hover-item {
-                    width: 50px;
-                    height: 50px;
-                    border-radius: 50%;
-                    margin-right: 1px;
-                }
-                .hover-item:hover {
-                    transform: scale(1.2);
-                    filter: grayscale(0%);
-                }
-                .share-button {
-                    background-color: #1da1f2;
-                    color: white;
-                    padding: 6px 12px;
-                    border-radius: 5px;
-                    border: none;
-                    font-size: 0.95em;
-                    margin-left: 5px;
-                    transition: all 0.2s ease;
-                }
-                .share-button:hover {
-                    transform: scale(1.1);
-                    filter: brightness(1.2);
-                }
-                .share-button.linkedin {
-                    background-color: #0077b5;
-                }
-                .share-button i {
-                    margin-right: 5px;
-                    font-size: 1.1em;
-                }
-            </style>
-            """
-            div += css
             div = BeautifulSoup(div, "html.parser")
             self.insert_content(soup, div)
 
         # Add share buttons to the footer, if enabled
-        if self.config["add_share_buttons"]:  # Check if share buttons are enabled
+        if self.config["add_share_buttons"]:
             twitter_share_link = f"https://twitter.com/intent/tweet?url={page_url}"
             linkedin_share_link = f"https://www.linkedin.com/shareArticle?url={page_url}"
 
-            # Updated HTML for share buttons
-            share_buttons = f"""
-            <div class="share-buttons">
-                <button onclick="window.open('{twitter_share_link}', 'TwitterShare', 'width=550,height=680,menubar=no,toolbar=no'); return false;" class="share-button hover-item">
-                    <i class="fa-brands fa-twitter"></i> Tweet
-                </button>
-                <button onclick="window.open('{linkedin_share_link}', 'LinkedinShare', 'width=550,height=730,menubar=no,toolbar=no'); return false;" class="share-button hover-item linkedin">
-                    <i class="fa-brands fa-linkedin"></i> Share
-                </button>
-            </div>
-            """
+            share_buttons = f"""<div class="share-buttons">
+    <button onclick="window.open('{twitter_share_link}', 'TwitterShare', 'width=550,height=680,menubar=no,toolbar=no'); return false;" class="share-button hover-item">
+        <i class="fa-brands fa-x-twitter"></i> Tweet
+    </button>
+    <button onclick="window.open('{linkedin_share_link}', 'LinkedinShare', 'width=550,height=730,menubar=no,toolbar=no'); return false;" class="share-button hover-item linkedin">
+        <i class="fa-brands fa-linkedin-in"></i> Share
+    </button>
+</div>
+"""
             share_buttons = BeautifulSoup(share_buttons, "html.parser")
             self.insert_content(soup, share_buttons)
 
@@ -466,3 +417,96 @@ class MetaPlugin(BasePlugin):
             soup.head.append(ld_json_script)
 
         return str(soup)
+
+    @staticmethod
+    def get_css():
+        """Simplified CSS with unified hover effects, closer author circles, and larger share buttons."""
+        return """
+.git-info, .dates-container, .authors-container, .share-buttons {
+    display: flex;
+    align-items: center;
+    justify-content: flex-end;
+    flex-wrap: wrap;
+}
+
+.git-info {
+    font-size: 0.8em;
+    color: grey;
+    margin-bottom: 10px;
+}
+
+.dates-container, .authors-container {
+    margin-bottom: 10px;
+}
+
+.date-item, .author-link, .share-button {
+    display: flex;
+    align-items: center;
+    cursor: pointer;
+}
+
+.date-item {
+    margin-right: 10px;
+}
+
+.hover-item {
+    transition: all 0.2s ease;
+    filter: grayscale(100%);
+}
+
+.date-item .hover-item {
+    font-size: 1.6em;
+    margin-right: 5px;
+}
+
+.author-link .hover-item {
+    width: 50px;
+    height: 50px;
+    border-radius: 50%;
+    margin-right: 3px;
+}
+
+.hover-item:hover {
+    transform: scale(1.2);
+    filter: grayscale(0%);
+}
+
+.share-buttons {
+    margin-top: 10px;
+}
+
+.share-button {
+    background-color: #1da1f2;
+    color: white;
+    padding: 6px 12px;
+    border-radius: 5px;
+    border: none;
+    font-size: 0.95em;
+    margin: 5px;
+    transition: all 0.2s ease;
+}
+
+.share-button:hover {
+    transform: scale(1.1);
+    filter: brightness(1.2);
+}
+
+.share-button.linkedin {
+    background-color: #0077b5;
+}
+
+.share-button i {
+    margin-right: 5px;
+    font-size: 1.1em;
+}
+
+@media (max-width: 1024px) {
+    .git-info {
+        flex-direction: column;
+        align-items: flex-end;
+    }
+    .dates-container, .authors-container {
+        width: 100%;
+    }
+}
+"""
